@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '1.19';
+$VERSION = '1.20';
 
 #----------------------------------------------------------------------------
 # Library Modules
@@ -461,12 +461,21 @@ sub get_tail_guids {
     my $guids;
 
     eval {
+#        $guids = $self->{librarian}->search(
+#        	'core.type'         => 'CPAN-Testers-Report',
+#        	'core.update_time'  => { ">", 0 },
+#        	'-desc'             => 'core.update_time',
+#        	'-limit'            => $self->{poll_limit},
+#    	);
         $guids = $self->{librarian}->search(
-        	'core.type'         => 'CPAN-Testers-Report',
-        	'core.update_time'  => { ">", 0 },
-        	'-desc'             => 'core.update_time',
-        	'-limit'            => $self->{poll_limit},
-    	);
+            '-where'  => [
+                '-and' =>
+                    [ '-eq' => 'core.type'         => 'CPAN-Testers-Report' ],
+                    [ '-ge' => 'core.update_time'  => 0 ]
+            ],
+            '-order'  => [ '-desc' => 'core.update_time' ],
+            '-limit'  => $self->{poll_limit},
+        );
     };
 
     $self->_log(" ... Metabase Tail Failed [$@]\n") if($@);
@@ -704,6 +713,11 @@ sub parse_report {
     $self->{report}{created} = $report->{metadata}{core}{creation_time};
     $self->{report}{updated} = $report->{metadata}{core}{update_time};
 
+    unless(ref($report) eq 'CPAN::Testers::Report') {
+        $self->{msg} .= ".. ref [" . ref($report) . "]";
+        return 1;
+    }
+
     my @facts = $report->facts();
     for my $fact (@facts) {
         if(ref $fact eq 'CPAN::Testers::Fact::TestSummary') {
